==> humhub-1.17.4.zip: humhub-1.17.4/protected/humhub/messages/zh-CN/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>确认</strong> 操作',
    '<strong>Latest</strong> updates' => '<strong>最近</strong> 更新',
    '<strong>Mail</strong> summary' => '<strong>邮件</strong> 概要',
    'Actions' => '动作',
    'Administration' => '管理',
    'All' => '所有',
    'Allow' => '允许',
    'An error occurred while handling your last action. (Handler not found).' => '执行最后一个操作出错。(处理器没有找到)',
    'An unexpected error occurred while loading the search result.' => '加载搜索结果时发生意外错误。',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => '发现了意外错误，如果一直出现该错误，请联系网站管理员',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => '发生意外的服务器错误。如果这种情况不断发生，请联系网站管理员',
    'Back' => '返回',
    'Back to dashboard' => '返回主面板',
    'Cancel' => '取消',
    'Choose language:' => '选择语言',
    'Close' => '关闭',
    'Collapse' => '折叠',
    'Confirm' => '确认',
    'Content Addon source must be instance of HActiveRecordContent or HActiveRecordContentAddon!' => '内容插件源必须是hactive record content或hactive record contentaddon实例',
    'Copy to clipboard' => '复制到剪贴板',
    'Could not find content of addon!' => '找不到内容的插件！',
    'Default' => '默认',
    'Delete' => '删除',
    'Deny' => '拒绝',
    'Do you really want to perform this action?' => '你真的要执行此操作吗？',
    'Edit' => '编辑',
    'Error' => '错误',
    'Error while running your last action (Invalid request method).' => '执行最后一个操作出错。(无效的请求方法)',
    'Error:' => '错误：',
    'Expand' => '展开',
    'Info:' => '信息：',
    'Invalid request method!' => '无效的请求方法！',
    'It looks like you may have taken the wrong turn.' => '看来出错了。',
    'Language' => '语言',
    'Loading...' => '加载中...',
    'Login' => '登录',
    'Logout' => '退出',
    'Menu' => '菜单',
    'Module is not enabled on this content container!' => '该内容容器上没有启用模块！',
    'New profile image' => '新图片',
    'Next' => '下一步',
    'No error information given.' => '没有给出错误消息。',
    'Oooops...' => '糟糕...',
    'Open' => '打开',
    'Please type at least 3 characters' => '请至少输入3个字符',
    'Save' => '保存',
    'Saved' => '已保存',
    'Search' => '搜索',
    'Settings' => '设置',
    'Show less' => '展示更少',
    'Show more' => '展示更多',
    'Some files could not be uploaded:' => '有些文件无法被上传：',
    'The date has to be in the past.' => '必须为过去的日期。',
    'The file has been deleted.' => '文件已被删除',
    'The requested resource could not be found.' => '未找到请求的资源',
    'The space has been archived.' => '空间已归档',
    'The space has been unarchived.' => '空间已解除归档',
    'Unsubscribe' => '退订',
    'Upload' => '上传',
    'You are not allowed to run this action.' => '你不被允许执行此操作。',
    'Add:' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Could not find requested page.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Export' => '',
    'Logo of {appName}' => '',
    'My Profile' => '',
    'No results' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Profile dropdown' => '',
    'Profile picture of {displayName}' => '',
    'Search...' => '',
    'Select Me' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Text could not be copied to clipboard' => '',
    'Text has been copied to clipboard' => '',
    'Time Zone' => '',
    'Toggle comment menu' => '',
    'Toggle panel menu' => '',
    'Toggle post menu' => '',
    'Toggle stream entry menu' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'Upload file' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];

==> humhub-1.18.0.zip: humhub-1.18.0/protected/humhub/messages/zh-CN/base.php <==
<?php

return [
    '<strong>Confirm</strong> Action' => '<strong>确认</strong> 操作',
    '<strong>Latest</strong> updates' => '<strong>最近</strong> 更新',
    '<strong>Mail</strong> summary' => '<strong>邮件</strong> 概要',
    'Actions' => '动作',
    'Administration' => '管理',
    'All' => '所有',
    'Allow' => '允许',
    'An error occurred while handling your last action. (Handler not found).' => '执行最后一个操作出错。(处理器没有找到)',
    'An unexpected error occurred while loading the search result.' => '加载搜索结果时发生意外错误。',
    'An unexpected error occurred. If this keeps happening, please contact a site administrator.' => '发现了意外错误，如果一直出现该错误，请联系网站管理员',
    'An unexpected server error occurred. If this keeps happening, please contact a site administrator.' => '发生意外的服务器错误。如果这种情况不断发生，请联系网站管理员',
    'Back' => '返回',
    'Back to dashboard' => '返回主面板',
    'Cancel' => '取消',
    'Choose language:' => '选择语言',
    'Close' => '关闭',
    'Collapse' => '折叠',
    'Confirm' => '确认',
    'Content Addon source must be instance of ContentActiveRecord or ContentAddonActiveRecord!' => '内容插件源必须是hactive record content或hactive record contentaddon实例',
    'Copy to clipboard' => '复制到剪贴板',
    'Could not find content of addon!' => '找不到内容的插件！',
    'Default' => '默认',
    'Delete' => '删除',
    'Deny' => '拒绝',
    'Do you really want to perform this action?' => '你真的要执行此操作吗？',
    'Edit' => '编辑',
    'Enter security code above' => '输入上面的安全码',
    'Error' => '错误',
    'Error while running your last action (Invalid request method).' => '执行最后一个操作出错。(无效的请求方法)',
    'Error:' => '错误：',
    'Expand' => '展开',
    'Info:' => '信息：',
    'Invalid request method!' => '无效的请求方法！',
    'It looks like you may have taken the wrong turn.' => '看来出错了。',
    'Language' => '语言',
    'Loading...' => '加载中...',
    'Login' => '登录',
    'Logout' => '退出',
    'Menu' => '菜单',
    'Module is not enabled on this content container!' => '该内容容器上没有启用模块！',
    'New profile image' => '新图片',
    'Next' => '下一步',
    'No error information given.' => '没有给出错误消息。',
    'Oooops...' => '糟糕...',
    'Open' => '打开',
    'Please type at least 3 characters' => '请至少输入3个字符',
    'Save' => '保存',
    'Saved' => '已保存',
    'Search' => '搜索',
    'Settings' => '设置',
    'Show less' => '展示更少',
    'Show more' => '展示更多',
    'Some files could not be uploaded:' => '有些文件无法被上传：',
    'The date has to be in the past.' => '必须为过去的日期。',
    'The file has been deleted.' => '文件已被删除',
    'The requested resource could not be found.' => '未找到请求的资源',
    'The space has been archived.' => '空间已归档',
    'The space has been unarchived.' => '空间已解除归档',
    'Unsubscribe' => '退订',
    'Upload' => '上传',
    'You are not allowed to run this action.' => '你不被允许执行此操作。',
    'Add:' => '',
    'Allow content from external source' => '',
    'Always allow content from this provider!' => '',
    'An unexpected error occurred. Please check whether your file exceeds the allowed upload limit of {maxUploadSize}.' => '',
    'Back to login' => '',
    'Could not find requested page.' => '',
    'Do you want to enable content from \'{urlPrefix}\'?' => '',
    'Export' => '',
    'I\'m not a robot' => '',
    'Logo of {appName}' => '',
    'My Profile' => '',
    'No results' => '',
    'Please type at least {count} characters' => '',
    'Powered by {name}' => '',
    'Profile dropdown' => '',
    'Profile picture of {displayName}' => '',
    'Search...' => '',
    'Select Me' => '',
    'Show all results' => '',
    'Stop impersonation' => '',
    'Switch network' => '',
    'Text could not be copied to clipboard' => '',
    'Text has been copied to clipboard' => '',
    'Time Zone' => '',
    'Toggle comment menu' => '',
    'Toggle panel menu' => '',
    'Toggle post menu' => '',
    'Toggle stream entry menu' => '',
    'Unsaved changes will be lost. Do you want to proceed?' => '',
    'Upload file' => '',
    'Verified' => '',
    'We couldn\'t verify that you\'re human. Please check the box again.' => '',
    'verify your upload_max_filesize and post_max_size php settings.' => '',
    '{attribute} has been empty. The system-configured function to fill empty values has returned an invalid value. Please try again or contact your administrator.' => '',
    '{attribute} must be a string (UUID) or null; {type} given.' => '',
    '{attribute} must be an UUID or null. UUID has the format "{{XXXXXXXX-XXXX-XXXX-XXXX-XXXXXXXXXXXX}}", where X = [a-fA-F0-9] and both curly brackets and delimiting dashes are optional.' => '',
    '{nFormatted}B' => '',
    '{nFormatted}K' => '',
    '{nFormatted}M' => '',
];
